@@ -23,7 +23,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "utils.h"
   
 // local
-char MSG[LENERRMSG], BUG_MSG[250], MSG2[LENERRMSG];
+char ERRMSG[LENERRMSG], MSG[LENERRMSG], BUG_MSG[250], MSG2[LENERRMSG];
 
 // globally needed
 char 
